Skip to contents

An experimental fork of 'stringr'. The functions and semantics are the same, apart from differences between 'ICU' and Unicode versions, but everything is optimized around 'ALTREP' strings (custom high-performance string storage), allowing for faster and more efficient operation.

Author

Maintainer: Travers Ching traversc@gmail.com [copyright holder]

Authors:

Other contributors:

  • Hadley Wickham hadley@posit.co (Author of stringr, of which charr is a fork) [contributor, copyright holder]

  • Posit Software, PBC (Copyright holder of stringr) [contributor, copyright holder]

  • Unicode, Inc. and others (ICU4C source code and data (Unicode License v3)) [contributor, copyright holder]

  • Marek Gagolewski (Author of stringi; stringi implementation used by charr) [contributor, copyright holder]

  • R Consortium (Infrastructure Steering Committee grant: Universal ALTREP Interoperability for Strings) [funder]