str_reverse() reverses the order of the Unicode code points in each
string.
See also
stringi::stri_reverse() for the underlying implementation.
Examples
str_reverse(c("abc", "caf\u00e9", NA))
#> [1] "cba" "éfac" NA
str_reverse() reverses the order of the Unicode code points in each
string.
stringi::stri_reverse() for the underlying implementation.
str_reverse(c("abc", "caf\u00e9", NA))
#> [1] "cba" "éfac" NA